@@ -8,11 +8,12 @@ LastEditTime: 2022-06-07 14:42:21
 import os
 
 try:
-    from setting import CPROFILE_LOG_PATH, DEBUG, LOG_PATH #type:ignore
+    from setting import CPROFILE_LOG_PATH, DEBUG, LOG_PATH  # type:ignore
 except:
     DEBUG = False
     CPROFILE_LOG_PATH = os.getcwd() + "/Logs"
     LOG_PATH = os.getcwd() + "/Logs"  # 根目录下
+import time
 
 __a__ = [
     "read_dataframe",
@@ -31,9 +32,7 @@ __a__ = [
 ################################################################################
 
 
-def read_dataframe(
-    source, DEBUG_source=None, query=None, columns=None, Logger=None
-):
+def read_dataframe(source, DEBUG_source=None, query=None, columns=None, Logger=None):
     """从数据库（Mongo、SQL）、文件（Excel）读入数据,根据source自动判断
     Args：
        source：数据源，数据库信息类或者excel文件地址
@@ -93,7 +92,7 @@ def _find_mongo_to_df(config, query=None, columns=None):
     PASSWORD = quote_plus(config.PASSWORD)
 
     mongo_url = f"mongodb://{config.USER}:{PASSWORD}@{config.HOST}:{config.PORT}/?authSource={config.AUTHENTICATION}&authMechanism=SCRAM-SHA-1"
-    myclient =  pymongo.MongoClient(mongo_url)
+    myclient = pymongo.MongoClient(mongo_url)
 
     mydb = myclient[config.DB]
     mycol = mydb[config.TABLE]
@@ -126,7 +125,7 @@ def _read_mysql_to_df(config, query=None, columns=None):
     if query:
         pass
     elif columns:
-        columns = [f'`{x}`' for x in columns]
+        columns = [f"`{x}`" for x in columns]
         cols = ",".join(columns)
         query = f"select {cols} from {config.TABLE}"
     else:
@@ -226,7 +225,7 @@ def _read_file(file_path, columns=None):
     else:
         raise KeyError("文件暂时不支持！")
     if columns:
-        df = df[[columns]]
+        df = df[columns]
     return df
 
 
@@ -393,9 +392,7 @@ class SingletonLogger:
         sh = logging.StreamHandler()
         fh.setLevel(logging.DEBUG)  # 输出到file的log等级的开关
         # 第三步，定义handler的输出格式
-        formatter = logging.Formatter(
-            "%(asctime)s - %(filename)s[line:%(lineno)d] - %(levelname)s: %(message)s"
-        )
+        formatter = logging.Formatter("%(asctime)s - %(filename)s[line:%(lineno)d] - %(levelname)s: %(message)s")
         fh.setFormatter(formatter)
         sh.setFormatter(formatter)
         # 第四步，将logger添加到handler里面
@@ -403,53 +400,72 @@ class SingletonLogger:
         self.logger.addHandler(sh)
 
 
-
 import json
 import datetime
 import logging
+
+
 class ComplexEncoder(json.JSONEncoder):
     def default(self, obj):
-        if isinstance(obj, datetime.datetime):    # 日期和时间
-            return obj.strftime('%Y-%m-%d %H:%M:%S')
-        elif isinstance(obj, datetime.date):    # 日期
-            return obj.strftime('%Y-%m-%d')
-        elif isinstance(obj, datetime.time):    # 时间
-            return obj.strftime('%H:%M:%S')
+        if isinstance(obj, datetime.datetime):  # 日期和时间
+            return obj.strftime("%Y-%m-%d %H:%M:%S")
+        elif isinstance(obj, datetime.date):  # 日期
+            return obj.strftime("%Y-%m-%d")
+        elif isinstance(obj, datetime.time):  # 时间
+            return obj.strftime("%H:%M:%S")
         else:
             return json.JSONEncoder.default(self, obj)
 
+
 class JSONFormatter(logging.Formatter):
-    REMOVE_ATTR = ["exc_text", "stack_info", "created", "msecs", "relativeCreated", "exc_info",
-                   "msg", "args", "levelno", "pathname", "lineno", "funcName", "thread",
-                   "threadName", "processName", "process"]
+    REMOVE_ATTR = [
+        "exc_text",
+        "stack_info",
+        "created",
+        "msecs",
+        "relativeCreated",
+        "exc_info",
+        "msg",
+        "args",
+        "levelno",
+        "pathname",
+        "lineno",
+        "funcName",
+        "thread",
+        "threadName",
+        "processName",
+        "process",
+    ]
+
     @classmethod
     def build_record(cls, record):
-        return {attr_name: record.__dict__[attr_name] for attr_name in record.__dict__ if attr_name not in cls.REMOVE_ATTR}
+        return {
+            attr_name: record.__dict__[attr_name] for attr_name in record.__dict__ if attr_name not in cls.REMOVE_ATTR
+        }
 
     @classmethod
     def set_format_time(cls, msg_dict):
         now = datetime.datetime.now()
         format_time = now.strftime("%Y-%m-%d %H:%M:%S")
-        msg_dict['datetime'] = format_time
+        msg_dict["datetime"] = format_time
         return format_time
 
     def format(self, record):
         msg_dict = self.build_record(record)
         self.set_format_time(msg_dict)  # set time
         if isinstance(record.msg, dict):
-            msg_dict['msg'] = record.msg  # set message
+            msg_dict["msg"] = record.msg  # set message
         else:
             if record.args:
-                msg_dict['msg'] = "'" + record.msg + "'," + str(record.args).strip('()')
+                msg_dict["msg"] = "'" + record.msg + "'," + str(record.args).strip("()")
             else:
-                msg_dict['msg'] = record.msg
+                msg_dict["msg"] = record.msg
         if record.exc_info:
-            msg_dict['exc_info'] = self.formatException(record.exc_info)
+            msg_dict["exc_info"] = self.formatException(record.exc_info)
         return json.dumps(msg_dict, ensure_ascii=False, cls=ComplexEncoder)
 
 
-
-def make_json_logger(name='root'):
+def make_json_logger(name="root"):
     """统一正式服务调用日志类，json格式，一般仅保留报错信息（存活监测5秒一次，并且接口信息java已经有日志）"""
 
     logger = logging.getLogger(name)
@@ -464,9 +480,7 @@ def make_json_logger(name='root'):
     sh = logging.StreamHandler()
     fh.setLevel(logging.INFO)  # 输出到file的log等级的开关
     # 第三步，定义handler的输出格式
-    formatter = logging.Formatter(
-        "%(asctime)s - %(filename)s[line:%(lineno)d] - %(levelname)s: %(message)s"
-    )
+    formatter = logging.Formatter("%(asctime)s - %(filename)s[line:%(lineno)d] - %(levelname)s: %(message)s")
     fh.setFormatter(JSONFormatter())
     sh.setFormatter(JSONFormatter())
     # 第四步，将logger添加到handler里面
@@ -502,17 +516,10 @@ def func_cprofile(f):
                 return result
             finally:
                 s = io.StringIO()
-                ps = (
-                    pstats.Stats(profile, stream=s)
-                    .sort_stats("cumulative")
-                    .print_stats(200)
-                )
+                ps = pstats.Stats(profile, stream=s).sort_stats("cumulative").print_stats(200)
                 if not os.path.exists(CPROFILE_LOG_PATH):
                     os.makedirs(CPROFILE_LOG_PATH)
-                with open(
-                    f'{CPROFILE_LOG_PATH}/{dt.now().strftime("%Y%m%d_%H%M%S")}_{name}_cProfile.log',
-                    "w",
-                ) as fp:
+                with open(f'{CPROFILE_LOG_PATH}/{dt.now().strftime("%Y%m%d_%H%M%S")}_{name}_cProfile.log', "w",) as fp:
                     fp.write(s.getvalue())
 
         return wrapper
@@ -646,12 +653,8 @@ class DataCheck:
             r_dict = {}
             last = self.__data[self.__count]
             compare = self.__data[index_]
-            r_dict["cols_add"] = [
-                x for x in last["columns"] if x not in compare["columns"]
-            ]
-            r_dict["cols_reduce"] = [
-                x for x in compare["columns"] if x not in last["columns"]
-            ]
+            r_dict["cols_add"] = [x for x in last["columns"] if x not in compare["columns"]]
+            r_dict["cols_reduce"] = [x for x in compare["columns"] if x not in last["columns"]]
             r_dict["target_reduce"] = last["target_len"] - compare["target_len"]
             r_dict["len_reduce"] = last["len"] - compare["len"]
 
